<!-- 新增编辑弹窗 -->
<template>
    <j-drawer v-model:visible="visible" :closable="false" class="custom-class" :title="props.title" width="800"
        placement="right" :footer-style="{ textAlign: 'right' }" @close="onClose">
        <j-form layout="vertical" ref="formRef" :rules="rules" :model="formModel">
            <j-row :gutter="16">
                <j-col class="gutter-row" :span="12">
                    <j-form-item label="所属库房" name="warehouseId">
                        <j-select style="width: 100%" v-model:value="formModel.warehouseId" placeholder="请选择单位">
                            <j-select-option v-for="item in storeData" :key="item.id" :value="item.id">
                                {{ item.name }}
                            </j-select-option>
                        </j-select>
                    </j-form-item>
                    <j-form-item label="设备名称" name="name">
                        <j-input v-model:value="formModel.name" :maxlength="64" placeholder="请输入设备名称" allowClear />
                    </j-form-item>
                    <j-form-item label="连接地址" name="linkAddress">
                        <j-input v-model:value="formModel.linkAddress" :maxlength="64" placeholder="请输入连接地址" allowClear />
                    </j-form-item>
                    <j-form-item label="列" name="cols">
                        <j-input v-model:value="formModel.cols" :maxlength="64" placeholder="请输入列" allowClear />
                    </j-form-item>
                    <j-form-item label="组" name="groups">
                        <j-input v-model:value="formModel.groups" :maxlength="64" placeholder="请输入组" allowClear />
                    </j-form-item>
                    <j-form-item label="负责人" name="custodian">
                        <j-input v-model:value="formModel.custodian" :maxlength="64" placeholder="请输入负责人" allowClear />
                    </j-form-item>
                </j-col>
                <j-col class="gutter-row" :span="12">
                    <j-form-item label="编码" name="code">
                        <j-input v-model:value="formModel.code" :maxlength="64" placeholder="请输入编码" allowClear />
                    </j-form-item>
                    <j-form-item label="存储类别" name="storageType">
                        <j-select style="width: 100%" v-model:value="formModel.storageType" placeholder="请选择存储类别">
                            <j-select-option value="库">库</j-select-option>
                            <j-select-option value="区">区</j-select-option>
                        </j-select>
                    </j-form-item>
                    <j-form-item label="品牌" name="brand">
                        <j-input v-model:value="formModel.brand" :maxlength="64" placeholder="请输入品牌" allowClear />
                    </j-form-item>
                    <j-form-item label="层" name="layers">
                        <j-input v-model:value="formModel.layers" :maxlength="64" placeholder="请输入层" allowClear />
                    </j-form-item>
                    <j-form-item label="出厂日期" name="manufactureDate">
                        <j-date-picker style="width: 100%" v-model:value="formModel.manufactureDate" allowClear />
                    </j-form-item>
                    <j-form-item label="负责人联系方式" name="phone">
                        <j-input v-model:value="formModel.phone" :maxlength="64" placeholder="请输入负责人联系方式" allowClear />
                    </j-form-item>
                </j-col>
            </j-row>
            <j-form-item label="备注">
                <j-input v-model:value="formModel.memo" :maxlength="64" placeholder="请输入备注" allowClear />
            </j-form-item>
            <j-form-item label="设备图片">
                <j-upload v-model:file-list="fileList" :action="imgUploadUrl" :headers="uploadHeaders"
                    list-type="picture-card" @preview="handlePreview">
                    <div v-if="fileList && fileList.length < 8">
                        <plus-outlined />
                        <div style="margin-top: 8px">点击上传</div>
                    </div>
                </j-upload>
                <j-modal :visible="previewVisible" :title="previewTitle" :footer="null" @cancel="handleCancel">
                    <img alt="example" style="width: 100%" :src="previewImage" />
                </j-modal>
            </j-form-item>
        </j-form>
        <template #footer>
            <j-space>
                <j-button @click="onClose">取消</j-button>
                <j-button type="primary" @click="submitData">保存</j-button>
            </j-space>
        </template>
    </j-drawer>
</template>
<script setup lang="ts" name="modifyDrawer">
import { PropType } from 'vue';
import { Form, message } from 'jetlinks-ui-components';
import { saveMJG, updateMJG } from '@/api/device-manager/mjg';
import { queryStoreNoPaging } from '@/api/warehouse/store';
import { PlusOutlined } from '@ant-design/icons-vue';
import type { UploadProps, UploadFile } from 'ant-design-vue';
import moment from 'moment';
import { LocalStore } from '@/utils/comm';
import { TOKEN_KEY } from '@/utils/variable';

const emits = defineEmits(['refresh']);
const formRef = ref();
const useForm = Form.useForm;
const props = defineProps({
    formData: {
        type: Object as PropType<Record<string, any>>,
        default: () => { },
    },
    title: {
        type: String,
        defult: '新增区域',
    },
    isAdd: {
        type: Number,
        default: 0,
    },
    isChild: {
        type: Number,
        default: 0,
    },
});
interface formState {
    id?: string;
    name: string;
    warehouseId: string;
    linkAddress: string;
    cols?: string;
    groups?: string;
    custodian?: string;
    code: string;
    storageType?: string;
    brand?: string;
    layers?: string;
    manufactureDate?: any;
    phone?: string;
    memo?: string;
    img?: string;
}
const storeData = ref<any>([]);
const updateObj = ref({});
const addParams = ref({});
const imgUploadUrl = import.meta.env.VITE_APP_BASE_API + "/file/static";
const uploadHeaders = {
    "X-Access-Token": LocalStore.get(TOKEN_KEY)
}
/**
 * 表单数据
 */
const formModel = ref<formState>({
    name: '',
    warehouseId: '',
    linkAddress: '',
    cols: '',
    groups: '',
    custodian: '',
    code: '',
    storageType: '',
    brand: '',
    layers: '',
    manufactureDate: '',
    phone: '',
    memo: '',
    img: ''
});

function getBase64(file: any) {
    return new Promise((resolve, reject) => {
        const reader = new FileReader();
        reader.readAsDataURL(file);
        reader.onload = () => resolve(reader.result);
        reader.onerror = error => reject(error);
    });
}
const previewVisible = ref(false);
const previewImage = ref<any>('');
const previewTitle = ref<any>('');

const fileList = ref<UploadProps['fileList']>([
    // {
    //     uid: '-1',
    //     name: 'image.png',
    //     status: 'done',
    //     url: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png',
    // }
]);
const rules = ref({
    name: [{ required: true, message: '请填写密集柜名称', trigger: 'change' }],
    warehouseId: [{ required: true, message: '请选择库房', trigger: 'change' }],
    code: [{ required: true, message: '请填写编码', trigger: 'change' }],
    linkAddress: [{ required: true, message: '请填写连接地址', trigger: 'change' }],
});
const visible = ref(false);
const { resetFields, validate, validateInfos } = useForm(
    formModel.value,
    rules.value,
);

onMounted(() => {
    queryStore();
});


const onClose = () => {
    visible.value = false;
};

const handleCancel = () => {
    previewVisible.value = false;
    previewTitle.value = '';
};

const handlePreview = async (file: UploadFile) => {
    if (!file.url && !file.preview) {
        file.preview = (await getBase64(file.originFileObj)) as string;
    }
    previewImage.value = file.url || file.preview;
    previewVisible.value = true;
    previewTitle.value = file.name || file.url?.substring(file.url.lastIndexOf('/') + 1);
};
/**
 * 查询库房数量，不分页
 */
const queryStore = async () => {
    let params = {
        paging: false,
        sorts: [
            { name: 'sortIndex', order: 'asc' },
            { name: 'createTime', order: 'desc' },
        ],
        where: '',
        terms: [],
    };
    const res = await queryStoreNoPaging(params);
    if (res.status === 200) {
        storeData.value = res.result;
    }
};

const filterOption = (input: string, option: any) => {
    return option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0;
};

/**
 * 提交数据
 */
const submitData = async () => {
    formRef.value.validate().then(async () => {
        addParams.value = {};
        let imgs = fileList.value?.map(item => {
            return {
                uid: item.uid,
                name: item.name,
                status: 'done',
                url: item.url || item.response?.result,
            }
        })
        // console.log("submitData:", imgs);
        if (props.isAdd === 0) {
            addParams.value = {
                ...formModel.value,
                manufactureDate: moment(formModel.value.manufactureDate).format('YYYY-MM-DD'),
                img: JSON.stringify(imgs)
            };
            const res = await saveMJG(addParams.value);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        } else if (props.isAdd === 2) {
            const id = formModel.value.id || '';
            const updateParams = {
                ...formModel.value,
                manufactureDate: moment(formModel.value.manufactureDate).format('YYYY-MM-DD'),
                img: JSON.stringify(imgs)
            };

            const res = await updateMJG(id, updateParams);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        }
    });
};
/**
 * 显示弹窗
 */
const show = async (row: any) => {
    // console.log("show:", row, props.isAdd);
    //新增
    if (props.isAdd === 0) {
        formModel.value = {
            name: '',
            warehouseId: '',
            code: '',
            linkAddress: ''
        };
        visible.value = true;
    } else if (props.isAdd === 2) {
        updateObj.value = row;
        // 编辑
        formModel.value = {
            id: row.id,
            name: row.name,
            warehouseId: row.warehouseId,
            code: row.code,
            linkAddress: row.linkAddress,
            cols: row.cols,
            groups: row.groups,
            custodian: row.custodian,
            storageType: row.storageType,
            brand: row.brand,
            layers: row.layers,
            manufactureDate: moment(row.manufactureDate),
            phone: row.phone,
            memo: row.memo
        };
        fileList.value = JSON.parse(row.img || "[]");
        visible.value = true;
    }
};

/**
 * 排序
 */
const compare = (property: any) => {
    return function (obj1: any, obj2: any) {
        var value1 = obj1[property];
        var value2 = obj2[property];
        return value1 - value2; // 升序
    };
};
/**
 * 关闭弹窗
 */
const close = () => {
    visible.value = false;
    resetFields();
};
//监听项目ID
watch([() => props.isAdd], () => { }, { immediate: false, deep: true });
defineExpose({
    show: show,
});
</script>
<style></style>
